@@ -457,6 +457,7 @@ static const EPS_UINT32 epsMediaTypeIndex[] = {
 #define	EPS_MPID_FRONT1		0x02
 #define	EPS_MPID_FRONT2		0x04
 #define	EPS_MPID_CDTRAY		0x08
+#define EPS_MPID_REARMANUAL	0x10
 //printer PAGE-S
 #define	EPS_MPID_PAGE_S_MP_TRAY				0x00
 #define	EPS_MPID_PAGE_S_CASSETTE1				0x01
@@ -471,7 +472,7 @@ static const EPS_UINT32 epsMediaTypeIndex[] = {
 #define	EPS_MPID_MPTRAY		0x100
 #define	EPS_MPID_FRONT3		0x200
 #define	EPS_MPID_FRONT4		0x400
-#define	EPS_MPID_ALL_ESCPR	(EPS_MPID_REAR | EPS_MPID_FRONT1 | EPS_MPID_FRONT2 | EPS_MPID_CDTRAY)
+#define	EPS_MPID_ALL_ESCPR	(EPS_MPID_REAR | EPS_MPID_FRONT1 | EPS_MPID_FRONT2 | EPS_MPID_CDTRAY | EPS_MPID_REARMANUAL)
 #define	EPS_MPID_ALL_ESCPAGE (EPS_MPID_MPTRAY | EPS_MPID_FRONT1 | EPS_MPID_FRONT2 | EPS_MPID_FRONT3 | EPS_MPID_FRONT4)
 
 
